@@ -7,8 +7,9 @@ use Carp;
 
 #require Exporter;
 use Mail::Miner::Assets;
+use UNIVERSAL::require;
 
-eval { 
+eval {
 require Mail::Miner::DBI;
 require Mail::Miner::Attachment;
 require Mail::Miner::Asset;
@@ -19,34 +20,45 @@ use MIME::Parser;
 
 #our @EXPORT_OK = ( );
 #our @EXPORT = qw( );
-our $VERSION = '2.5';
+our $VERSION = '2.7';
+our %recognisers;
 
 # Find all Mail::Miner::Recogniser modules
 use File::Spec::Functions qw(:DEFAULT splitdir);
 
-{ local $_=$_; # Breaking $_ considered evil
+sub import { 
+    my ($class, @modules) = @_;
+    local $_=$_; # Breaking $_ considered evil
+    for (@modules) {
+        eval "require $_";
+        die $@ if $@;
+    }
+    return if @modules;
 
 my @files = grep length, map { glob(catfile($_,"*.pm"))  }
-           grep { -d $_ }
-            map { catdir($_, "Mail", "Miner", "Recogniser") }
-            exists $INC{"blib.pm"} ? grep {/blib/} @INC : 
+            grep { -d $_ }
+            map { my $path = $_;
+                  catdir($path, "Mail", "Miner", "Recogniser"),
+            }
+            exists $INC{"blib.pm"} ? grep {/blib/} @INC :
             @INC;
 my %seen;
-@files = grep {!$seen{$_}++} @files;
+@files = grep {
+    my $key = $_;
+    $key =~ s|.*Mail/Miner/Recogniser||;
+     !$seen{$key}++
+    } @files;
 
 
 my @dummy = @files;
 for my $x (@dummy) {
     require $x; # No need for import.
-} 
-
-no warnings 'once';
-
-sub modules { sort keys %Mail::Miner::recognisers };
-
-sub plugins { map { $Mail::Miner::recognisers{$_}{keyword} => $_ } modules() };
+}
 
 }
+sub modules { sort keys %recognisers };
+
+sub plugins { map { $recognisers{$_}{keyword} => $_ } modules() };
 our $parser = new MIME::Parser;
 $parser->output_to_core(1);
 # Preloaded methods go here.
@@ -111,7 +123,7 @@ convenient to.
 Everything else that C<Mail::Miner> finds out about a mail is an
 B<asset>. For instance, a very trivial asset is the date it was sent. A
 more complex asset could be the fact that it looks like it contains a
-phone number, and what the phone number is. 
+phone number, and what the phone number is.
 
 =head2 Recognisers
 
